@@ -118,7 +118,7 @@ class TransactionsAPIView(APIView):
 
         # validate fields separately since error responses need different format
         missing_fields = validate_post_fields(
-            params.get("fields"), params.get("asset"), params.get("lang")
+            request, params.get("fields"), params.get("asset"), params.get("lang")
         )
         if missing_fields:
             return Response(
@@ -206,21 +206,18 @@ def validate_post_request(request: Request) -> Dict:
 
 
 def validate_post_fields(
-    passed_fields: Dict, asset: Asset, lang: Optional[str]
+    request: Request, passed_fields: Dict, asset: Asset, lang: Optional[str]
 ) -> Dict:
     missing_fields = defaultdict(dict)
-    expected_fields = registered_sep31_receiver_integration.info(asset, lang).get(
-        "fields", {}
-    )
+    expected_fields = registered_sep31_receiver_integration.info(
+        request=request, asset=asset, lang=lang
+    ).get("fields", {})
     if "transaction" not in expected_fields:
         return {}
-    elif "transaction" not in passed_fields:
-        missing_fields["transaction"] = expected_fields["transaction"]
-        return missing_fields
     for field, info in expected_fields["transaction"].items():
         if info.get("optional"):
             continue
-        elif field not in passed_fields["transaction"]:
+        elif field not in passed_fields.get("transaction", {}):
             missing_fields["transaction"][field] = info
     return dict(missing_fields)
 
